Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type LogEntry ¶ added in v0.0.15
type LogEntry struct {
Time time.Time
Level string
Message string
Attrs map[string]any
AttrJSON string // cached JSON string for Attrs (filtered)
}
LogEntry represents a log message
type ProbeLogEntry ¶ added in v0.0.9
type ProbeLogEntry = types.ProbeLogEntry
Use types.ProbeLogEntry instead of local definition
type TUIHandler ¶ added in v0.0.15
type TUIHandler struct {
// contains filtered or unexported fields
}
TUIHandler is a custom slog.Handler that sends logs to the TUI
func NewTUIHandler ¶ added in v0.0.15
func NewTUIHandler(logChan chan<- LogEntry, next slog.Handler) *TUIHandler
NewTUIHandler creates a new TUI handler that sends logs to the given channel and also forwards to the next handler (for console output)
func (*TUIHandler) Enabled ¶ added in v0.0.15
Enabled reports whether the handler handles records at the given level
type TUIModel ¶
type TUIModel struct {
// contains filtered or unexported fields
}
TUIModel represents the TUI application state
func (*TUIModel) GetLogChannel ¶ added in v0.0.15
GetLogChannel returns the log channel for external log writers
Click to show internal directories.
Click to hide internal directories.